# This function linearly interpolates the data generated by a vector post
# processor. The purpose is to have a function take points and a field variable
# (aux or primary) as arguments.
# It also uses a ConstantVectorPostprocessor to test that parallel syncing is
# working for VectorPostprocessorFunction.
[Mesh]
  type = GeneratedMesh
  dim = 2
  nx = 2
  ny = 4
  xmin = 0.0
  xmax = 0.004
  ymin = 0.0
  ymax = 0.008
[]

[Variables]
  [u]
    initial_condition = 0
  []
[]

[AuxVariables]
  [v]
    initial_condition = 1
  []
  [test_parallel]
  []
[]

[Functions]
  [ramp_u]
    type = ParsedFunction
    expression = 't'
  []
  [point_value_function_u]
    type = VectorPostprocessorFunction
    component = y
    argument_column = y
    value_column = u
    vectorpostprocessor_name = point_value_vector_postprocessor_u
  []
  [line_value_function_v]
    type = VectorPostprocessorFunction
    component = y
    argument_column = y
    value_column = v
    vectorpostprocessor_name = line_value_vector_postprocessor_v
  []
  [test_parallel_func]
    type = VectorPostprocessorFunction
    component = x
    argument_column = xx
    value_column = qq
    vectorpostprocessor_name = test_parallel_vpp
  []
  [function_v]
    type = PiecewiseLinear
    x = '0 0.008'
    y = '1 2'
    axis = y
  []
[]

[Kernels]
  [diffusion_u]
    type = Diffusion
    variable = u
  []
[]

[AuxKernels]
  [aux_v]
    type = FunctionAux
    variable = v
    function = function_v
    execute_on = 'TIMESTEP_BEGIN'
  []
  [test_parallel]
    type = FunctionAux
    variable = test_parallel
    function = test_parallel_func
    execute_on = 'TIMESTEP_END'
  []
[]

[BCs]
  [top_u]
    type = FunctionDirichletBC
    boundary = top
    variable = u
    function = ramp_u
  []
  [bottom_u]
    type = DirichletBC
    boundary = bottom
    variable = u
    value = 0
  []
[]

[Executioner]
  type = Transient
  solve_type = 'PJFNK'
  petsc_options = '-snes_ksp_ew'
  petsc_options_iname = '-pc_type -pc_factor_mat_solver_package -ksp_gmres_restart'
  petsc_options_value = ' lu       superlu_dist                 51'
  line_search = 'none'
  l_max_its = 50
  l_tol = 1e-3
  nl_max_its = 20
  nl_rel_tol = 1e-4
  nl_abs_tol = 1e-6
  start_time = 0
  num_steps = 1
  dt = 1
[]
[Postprocessors]
  [point_value_postprocessor_u]
    type = FunctionValuePostprocessor
    function = point_value_function_u
    point = '0.002 0.004 0'
  []
  [line_value_postprocessor_v]
    type = FunctionValuePostprocessor
    function = line_value_function_v
    point = '0.002 0.004 0'
  []
  [postprocessor_average_u]
    type = ElementAverageValue
    variable = u
  []
  [postprocessor_average_v]
    type = ElementAverageValue
    variable = v
  []
[]
[VectorPostprocessors]
  [point_value_vector_postprocessor_u]
    type = PointValueSampler
    variable = u
    points = '0 0.001 0 0 0.004 0 0 0.008 0'
    #points = '0.001 0 0 0.002 0 0'
    sort_by = y
    execute_on = linear
  []
  [line_value_vector_postprocessor_v]
    type = LineValueSampler
    variable = v
    start_point = '0 0.001 0'
    end_point = '0 0.008 0'
    num_points = 5
    sort_by = y
    execute_on = linear
  []
  [test_parallel_vpp]
    type = ConstantVectorPostprocessor
    vector_names = 'xx qq'
    value = '0    1;
             1000 1000'
    execute_on = 'initial timestep_begin'
  []
[]
[Outputs]
  interval = 1
  csv = false
  exodus = true
  file_base = out
  [console]
    type = Console
    output_linear = true
    max_rows = 10
  []
[]
